@@ -522,6 +522,17 @@ fn main() {
         ("pub const UNIT_T:", "phydat_unit_t"),
         // See https://github.com/RIOT-OS/RIOT/pull/17660, available after 2022.01
         ("vfs_iterate_mount_dirs", "vfs_iterate_mount_dirs"),
+        // Experimental markers
+        //
+        // These are not merged in RIOT yet, but promising candidates; if there are any substantial
+        // changes to them, their marker name will be bumped, but it is expected that they will be
+        // moved up and get an "available after" release once merged.
+
+        // See https://github.com/RIOT-OS/RIOT/pull/17758 retrofitting it for the change in
+        // https://github.com/RIOT-OS/RIOT/pull/17351, available TBD
+        ("ztimer_periodic_callback_t", "ztimer_periodic_callback_t"),
+        // See https://github.com/RIOT-OS/RIOT/pull/17544, available TBD
+        ("coap_build_pkt_t", "coap_build_pkt_t"),
     ];
     for (needle, name) in markers {
         if bindgen_output.contains(needle) {
